@@ -57,7 +57,7 @@ def preview_whatap_conf(option_name:str):
     현재 preview_whatap_conf 를 사용중인 옵션
     - ignore_whatap_stdout (False)
     - standalone_enabled (False)
-    - open_file_descriptor_enabled (False)
+    - counter_thread_enabled (False)
     """
     value = 'false'
     try:
@@ -412,27 +412,84 @@ def go(batch=False, opts={}):
         file_name = AGENT_NAME + '.pid.batch'
 
     def get_pname(pid):
-        cmdlinepath = os.path.join('/proc', str(pid), 'cmdline')
-        if os.path.exists(cmdlinepath):
-            with open(cmdlinepath) as f:
-                content = f.read()
-                if content:
-                    return content.strip()
+        # Linux/Unix: use /proc filesystem
+        if sys.platform != 'win32':
+            cmdlinepath = os.path.join('/proc', str(pid), 'cmdline')
+            if os.path.exists(cmdlinepath):
+                with open(cmdlinepath) as f:
+                    content = f.read()
+                    if content:
+                        return content.strip()
+        else:
+            # Windows: use psutil to get process name
+            try:
+                import psutil
+                process = psutil.Process(int(pid))
+                return ' '.join(process.cmdline())
+            except:
+                pass
         return ''
+
     pid = read_file(home, file_name)
     if pid and get_pname(pid).find('whatap_python') >= 0:
-        os.kill(int(pid), signal.SIGKILL)
-        
+        if sys.platform == 'win32':
+            # Windows: Don't kill, just skip
+            whatap_print('WHATAP: Agent already running (PID: {}). Skipping duplicate execution.'.format(pid))
+            return
+        else:
+            # Unix/Linux: kill and replace existing process
+            try:
+                import signal
+                os.kill(int(pid), signal.SIGKILL)
+            except Exception:
+                pass
+
     try:
         home_path= os.environ.get(home)
-        if os.path.exists(os.path.join(home_path, AGENT_NAME)):
-            os.remove(os.path.join(home_path, AGENT_NAME))
 
-        source_cwd = os.path.join(os.path.join(os.path.dirname(__file__), 'agent'), platform.system().lower(),
-                                  ARCH[platform.machine()])
+        # Windows uses .exe extension
+        agent_binary_name = AGENT_NAME + '.exe' if sys.platform == 'win32' else AGENT_NAME
+        dest_agent = os.path.join(home_path, agent_binary_name)
 
-        os.symlink(os.path.join(source_cwd, AGENT_NAME),
-                   os.path.join(home_path, AGENT_NAME))
+        # Try to remove existing binary
+        # Windows: File may still be locked even after waiting, ignore error and use existing binary
+        # Unix/Linux: Removal should always succeed
+        needs_deployment = False
+        if os.path.exists(dest_agent):
+            try:
+                os.remove(dest_agent)
+                needs_deployment = True
+            except (OSError, PermissionError) as e:
+                if sys.platform == 'win32':
+                    # Windows: File is still locked, use existing binary
+                    pass
+                else:
+                    # Unix/Linux: This should not happen
+                    raise
+        else:
+            needs_deployment = True
+
+        # Windows doesn't use architecture subdirectories (only single x64 binary for now)
+        if sys.platform == 'win32':
+            source_cwd = os.path.join(os.path.dirname(__file__), 'agent', 'windows')
+        else:
+            source_cwd = os.path.join(os.path.join(os.path.dirname(__file__), 'agent'), platform.system().lower(),
+                                      ARCH[platform.machine()])
+
+        source_agent = os.path.join(source_cwd, agent_binary_name)
+
+        # Deploy agent binary only if needed
+        if needs_deployment:
+            # Try symlink first (Unix/Linux or Windows with proper permissions)
+            try:
+                os.symlink(source_agent, dest_agent)
+            except (OSError, NotImplementedError):
+                # Fallback to copy on Windows or when symlink fails
+                import shutil
+                shutil.copy2(source_agent, dest_agent)
+                # Make executable on Unix-like systems
+                if sys.platform != 'win32':
+                    os.chmod(dest_agent, 0o755)
 
         sockfile_path = os.path.join(home_path, 'run')
         if not os.path.exists(sockfile_path):
@@ -440,10 +497,39 @@ def go(batch=False, opts={}):
         newenv['whatap.enabled'] = 'True'
         newenv['WHATAP_PID_FILE'] = file_name
         newenv['PYTHON_PARENT_APP_PID'] = str(os.getpid())
-        process = subprocess.Popen(['./{0}'.format(AGENT_NAME), '-t', '3', '-d', '1'],
-                                   cwd=home_path,env=newenv, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdouts, errs = process.communicate()
-        whatap_print("executed golang module ", str(stdouts,"utf8"), str(errs, "utf8"))
+
+        # Windows uses absolute path, Unix/Linux uses relative path
+        if sys.platform == 'win32':
+            agent_cmd = os.path.join(home_path, agent_binary_name)
+        else:
+            agent_cmd = './{0}'.format(agent_binary_name)
+
+        # Windows: Use -t flag only (no -d flag support) and run in background with DETACHED_PROCESS
+        # Unix/Linux: Use -t and -d flags, daemon mode handles background execution
+        if sys.platform == 'win32':
+            # Windows: Run in detached background process
+            DETACHED_PROCESS = 0x00000008
+            process = subprocess.Popen([agent_cmd, '-t', '3','foreground'],
+                                       cwd=home_path, env=newenv,
+                                       creationflags=DETACHED_PROCESS,
+                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            # Give it a moment to start
+            time.sleep(0.5)
+            if process.poll() is not None:
+                # Process ended unexpectedly, read output
+                stdouts, errs = process.communicate()
+                whatap_print("executed golang module ", str(stdouts,"utf8"), str(errs, "utf8"))
+            else:
+                # Write PID to file for process tracking
+                write_file(home, file_name, str(process.pid))
+                whatap_print("executed golang module in background (PID: {})".format(process.pid))
+        else:
+            # Unix/Linux: Run with daemon flag
+            process = subprocess.Popen([agent_cmd, '-t', '3', '-d', '1'],
+                                       cwd=home_path, env=newenv,
+                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            stdouts, errs = process.communicate()
+            whatap_print("executed golang module ", str(stdouts,"utf8"), str(errs, "utf8"))
     except Exception as e:
         import traceback
         traceback.print_exc()
@@ -538,7 +624,7 @@ def batch_profiling(fn):
         callback = None
         try:
             ctx = TraceContext()
-            ctx.service_name=module.__file__.split('/').pop()
+            ctx.service_name=os.path.basename(module.__file__)
             ctx = start_interceptor(ctx)
             
             callback = fn(*args, **kwargs)
@@ -552,9 +638,33 @@ def batch_profiling(fn):
     return trace
 
 
-import fcntl, os, time
+import os, time
 import errno
-def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', '/tmp/whatap-python.lock')):
+import sys
+
+try:
+    import fcntl
+    HAS_FCNTL = True
+except ImportError:
+    # fcntl is not available on Windows
+    HAS_FCNTL = False
+    if sys.platform == 'win32':
+        try:
+            import msvcrt
+            HAS_MSVCRT = True
+        except ImportError:
+            HAS_MSVCRT = False
+    else:
+        HAS_MSVCRT = False
+
+# Windows uses different default temp path
+if sys.platform == 'win32':
+    import tempfile
+    default_lock_file = os.path.join(tempfile.gettempdir(), 'whatap-python.lock')
+else:
+    default_lock_file = '/tmp/whatap-python.lock'
+
+def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', default_lock_file)):
     f = None
     i=0
     while f == None and i < 100:
@@ -573,7 +683,17 @@ def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', '/tmp/whatap-python
 
     if f:
         try:
-            fcntl.lockf(f, fcntl.LOCK_EX)
+            if HAS_FCNTL:
+                fcntl.lockf(f, fcntl.LOCK_EX)
+            elif HAS_MSVCRT:
+                # Windows file locking using msvcrt
+                try:
+                    # Use non-blocking lock to avoid OSError
+                    msvcrt.locking(f.fileno(), msvcrt.LK_NBLCK, 1)
+                except OSError:
+                    # File already locked by another process, skip locking
+                    pass
+            # If no locking mechanism available, proceed without lock
             return f
         except Exception as e:
             whatap_print(e)
@@ -581,6 +701,7 @@ def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', '/tmp/whatap-python
                 f.close()
             except:
                 pass
+    return None
 
 def get_port_number(port=6600, home=os.environ.get('WHATAP_HOME')):
     if not home:
@@ -610,10 +731,20 @@ def get_port_number(port=6600, home=os.environ.get('WHATAP_HOME')):
         else:
             lastPortFound += 1
         f.write(str(lastPortFound))
-        f.write('\t')    
+        f.write('\t')
         f.write(home)
-        f.write('\n')    
-        fcntl.lockf(f, fcntl.LOCK_UN)
+        f.write('\n')
+        try:
+            if HAS_FCNTL:
+                fcntl.lockf(f, fcntl.LOCK_UN)
+            elif HAS_MSVCRT:
+                # Windows file unlocking using msvcrt
+                try:
+                    msvcrt.locking(f.fileno(), msvcrt.LK_UNLCK, 1)
+                except OSError:
+                    pass
+        except:
+            pass
         f.close()
         return lastPortFound
             
@@ -638,11 +769,16 @@ def find_whatap_conf():
 
     # 2. 상위 디렉토리들 검색
     current = parent_dir
-    while current != '/':
+    # Cross-platform root detection: keep going until dirname doesn't change
+    while True:
         conf_path = os.path.join(current, 'whatap.conf')
         if os.path.exists(conf_path):
             os.environ['WHATAP_HOME'] = current
             return conf_path
-        current = os.path.dirname(current)
+        parent = os.path.dirname(current)
+        # Stop at root (Unix: '/', Windows: 'C:\' or similar)
+        if parent == current:
+            break
+        current = parent
 
     return None
\ No newline at end of file
