@@ -1,4 +1,5 @@
 import logging as logging_module
+import os
 import traceback
 from whatap.conf.configure import Configure as conf
 from whatap.net import async_sender
@@ -15,6 +16,8 @@ from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap import logging
 import sys
 
+from whatap.util.frame_util import get_current_frame
+
 SCOPE_ARGS_LENGTH = 2
 HEADER = 'headers'
 PATH = 'path'
@@ -123,7 +126,7 @@ def getUserId(scope, headers, defValue):
         cookie = headers.get(COOKIE, "")
         if cookie:
             if len(cookie) >= conf.trace_user_cookie_limit:
-                return defValue
+                return hash_util.hashFromString(defValue) if defValue else 0, defValue or ""
 
             x1 = cookie.find(UseridUtil.WHATAP_R)
             if x1 >= 0:
@@ -138,6 +141,7 @@ def getUserId(scope, headers, defValue):
     except Exception:
         exc_type, exc_value, exc_traceback = sys.exc_info()
         logger.debug("A502", 10, str(exc_value))
+        return hash_util.hashFromString(defValue) if defValue else 0, defValue or ""
 
 def interceptor_error_asgi(ctx, status_code, errors):
     ctx.status = int(status_code/ 100)
@@ -145,7 +149,7 @@ def interceptor_error_asgi(ctx, status_code, errors):
         ctx.error = 1
 
         error = ''
-        frame = sys._current_frames().get(ctx.thread.ident)
+        frame = get_current_frame(ctx)
         if not frame:
             return
 
@@ -154,8 +158,7 @@ def interceptor_error_asgi(ctx, status_code, errors):
             line_num = stack[1]
             method_name = stack[2]
 
-            if line.find('/whatap/trace') > -1 or line.find(
-                    '/threading.py') > -1:
+            if 'whatap' + os.sep + 'trace' in line or 'threading.py' in line:
                 continue
             error += '{} ({}:{})\n'.format(method_name, line, line_num)
 
@@ -260,4 +263,4 @@ def instrument_asgi(module):
         return trace
 
     ### module 있는지 체크 하고 파일을 분리해야함.
-    module.ASGIHandler.__call__ = wrapper(module.ASGIHandler.__call__)
\ No newline at end of file
+    module.ASGIHandler.__call__ = wrapper(module.ASGIHandler.__call__)
