@@ -51,12 +51,12 @@ def getUserId(headers,  defValue):
             ticket = headers.get(conf.user_header_ticket)
             if  ticket:
                 return hash_util.hashFromString(ticket), ticket
-            return 0,""
+            return 0, ""
         cookie = headers.get("cookie")
 
         if cookie:
             if len(cookie) >= conf.trace_user_cookie_limit :
-                return defValue
+                return hash_util.hashFromString(defValue) if defValue else 0, defValue or ""
 
             x1 = cookie.find(userid_util.WHATAP_R)
             if x1 >= 0:
@@ -66,11 +66,12 @@ def getUserId(headers,  defValue):
                 else:
                     value = cookie[x1 + len(userid_util.WHATAP_R) + 1:]
                 return hexa32.toLong32(value), value
-        userid=KeyGen.next()
+        userid = KeyGen.next()
         return userid, hexa32.toString32(userid)
     except Exception:
         exc_type, exc_value, exc_traceback = sys.exc_info()
-        logger.debug("A057",10, str(exc_value))
+        logger.debug("A057", 10, str(exc_value))
+        return hash_util.hashFromString(defValue) if defValue else 0, defValue or ""
 
 def getRemoteAddr(headers, whatap_dict):
     if conf.trace_http_client_ip_header_key:
@@ -443,6 +444,7 @@ def instrument_applications(module):
         async def trace(instance, scope, receive, send):
             if scope["type"] != "http":
                 await fn(instance, scope, receive, send)
+                return
             TraceContext()
             try:
                 await fn(instance, scope, receive, send)
