@@ -1,3 +1,4 @@
+import os
 import traceback
 
 import sys
@@ -19,6 +20,9 @@ from whatap.util.hexa32 import Hexa32
 import traceback, threading
 
 
+from whatap.util.frame_util import get_current_frame, set_greenlet_info
+
+
 def isEventlet():
     greenlet = sys.modules.get('greenlet')
 
@@ -77,6 +81,36 @@ def trace_handler(fn, start=False, preload=None):
 
     return handler
 
+def async_trace_handler(fn, start=False, preload=None):
+    def handler(func):
+        @wraps(func)
+        async def wrapper(*args, **kwargs):
+            if preload:
+                preload(*args, **kwargs)
+
+            ctx = TraceContextManager.getLocalContext()
+
+            if not start and not ctx:
+                return await fn(*args, **kwargs)
+
+            try:
+                callback = await func(*args, **kwargs)
+            except Exception as e:
+                if ctx and ctx.error_step == e:
+                    ctx.error_step = None
+                    raise e
+                raise
+            else:
+                if ctx and ctx.error_step:
+                    e = ctx.error_step
+                    ctx.error_step = None
+                    raise e
+                return callback
+
+        return wrapper
+
+    return handler
+
 
 def start_interceptor(ctx):
     if conf.dev:
@@ -242,7 +276,7 @@ def interceptor_error(status_code, errors, ctx=None):
         ctx.error = 1
 
         error = ''
-        frame = sys._current_frames().get(ctx.thread.ident)
+        frame = get_current_frame(ctx)
         if not frame:
             return
 
@@ -251,8 +285,7 @@ def interceptor_error(status_code, errors, ctx=None):
             line_num = stack[1]
             method_name = stack[2]
 
-            if line.find('/whatap/trace') > -1 or line.find(
-                    '/threading.py') > -1:
+            if 'whatap' + os.sep + 'trace' in line or 'threading.py' in line:
                 continue
             error += '{} ({}:{})\n'.format(method_name, line, line_num)
 
@@ -263,6 +296,7 @@ def interceptor_error(status_code, errors, ctx=None):
 
 
 def interceptor_step_error(e, ctx=None):
+    from whatap.trace.mod.database.util import extract_db_error_message
     if not ctx:
         ctx = TraceContextManager.getLocalContext()
     if not ctx:
@@ -278,7 +312,7 @@ def interceptor_step_error(e, ctx=None):
     errors.append(error_message)
 
     error = ''
-    frame = sys._current_frames().get(ctx.thread.ident)
+    frame = get_current_frame(ctx)
     if not frame:
         return
 
@@ -287,7 +321,7 @@ def interceptor_step_error(e, ctx=None):
         line_num = stack[1]
         method_name = stack[2]
 
-        if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
+        if 'whatap' + os.sep + 'trace' in line or 'threading.py' in line:
             continue
         error += '{} ({}:{})\n'.format(method_name, line, line_num)
 
@@ -301,25 +335,6 @@ def interceptor_step_error(e, ctx=None):
         async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
 
-def extract_db_error_message(e):
-    try:
-        # PostgreSQL (psycopg2)
-        if hasattr(e, 'pgcode') and hasattr(e, 'pgerror'):
-            return str(e.pgerror)
-
-        # MySQL (PyMySQL, mysql-connector-python)
-        if hasattr(e, 'args') and len(e.args) > 1 and isinstance(e.args[1], str):
-            return e.args[1]
-
-        # 기본 에러 메시지
-        if hasattr(e, 'args') and len(e.args) > 0:
-            if isinstance(e.args[0], str):
-                return e.args[0]
-            return str(e.args[0])
-
-        return str(e)
-    except:
-        return "Unknown database error"
 
 
 def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
@@ -329,8 +344,8 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
             return fn(*args, **kwargs)
         except Exception as e:
             interceptor_step_error(e, ctx=ctx)
-        finally:
-            return
+            raise
+
     param = None
     method = None
     if httpc_url.find('?') > -1:
@@ -385,213 +400,6 @@ def interceptor_sock_connect(fn, *args, **kwargs):
         ctx.socket_connecting = False
 
 
-def interceptor_db_con(fn, db_info, *args, **kwargs):
-    ctx = TraceContextManager.getLocalContext()
-    if not ctx:
-        return fn(*args, **kwargs)
-
-    start_time = DateUtil.nowSystem()
-    ctx.start_time = start_time
-
-    ctx.db_opening = True
-    try:
-        callback = fn(*args, **kwargs)
-    finally:
-        ctx.db_opening = False
-
-    if not kwargs:
-        kwargs = dict(
-            x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
-
-    db_type = db_info.get('type')
-
-    if db_type == "sqlite":
-        text = "sqlite:"
-    else:
-        text = '{}://'.format(db_type)
-        text += kwargs.get('user', '')
-        text += "@"
-        text += kwargs.get('host', kwargs.get('dsn', ''))
-        text += '/'
-
-    text += kwargs.get('database', kwargs.get('db', kwargs.get('dbname', '')))
-    ctx.active_dbc = text
-    ctx.lctx['dbc'] = text
-
-    ctx.active_dbc = 0
-
-    datas = [text]
-    ctx.elapsed = DateUtil.nowSystem() - start_time
-    async_sender.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
-
-    return callback
-
-
-def addQuoteDict(arg_dict):
-    quoted_dict = dict()
-
-    for k, v in arg_dict.items():
-        if isinstance(v, str):
-            quoted_dict[k] = "'" + v.replace("'", "\\'") + "'"
-        else:
-            quoted_dict[k] = v
-
-    return quoted_dict
-
-
-def addQuoteList(arg_list):
-    quoted_list = list()
-
-    for v in arg_list:
-        if isinstance(v, str):
-            quoted_list.append("'" + v.replace("'", "\\'") + "'")
-        else:
-            quoted_list.append("'" + str(v) + "'")
-
-    return tuple(quoted_list)
-
-def neo4jQuery(query,paremeter):
-    neo4j_query = query
-
-    for key, value in paremeter.items():
-        placeholder = f"${key}"
-        replacement = f"'{str(value)}'"
-        neo4j_query = neo4j_query.replace(placeholder, replacement)
-
-    return neo4j_query
-
-def sqliteQuery(query, paremeter):
-    sqlite_query = query
-
-    def quote(v):
-        if v is None: return "NULL"
-        if isinstance(v, (bytes, bytearray)): return "X'" + v.hex() + "'"
-        return "'" + str(v).replace("'", "''") + "'"
-
-    # 이름 기반: :name / @name / $name (단일 세트)
-    if isinstance(paremeter, dict):
-        for pfx in (':', '@', '$'):
-            for k, v in paremeter.items():
-                sqlite_query = sqlite_query.replace(f"{pfx}{k}", quote(v))
-        return sqlite_query
-
-    # 포지셔널 + executemany 분기
-    if isinstance(paremeter, (list, tuple)):
-        # ── executemany: [tuple|dict, ...] ──
-        if isinstance(paremeter, list) and paremeter and isinstance(paremeter[0], (tuple, dict)):
-            stmts = []
-            for params in paremeter:
-                sqlite_query = query
-                if isinstance(params, dict):
-                    for pfx in (':', '@', '$'):
-                        for k, v in params.items():
-                            sqlite_query = sqlite_query.replace(f"{pfx}{k}", quote(v))
-                else:  # tuple
-                    for i, v in enumerate(params, 1):
-                        sqlite_query = sqlite_query.replace(f"?{i}", quote(v))
-                    for v in params:
-                        sqlite_query = sqlite_query.replace('?', quote(v), 1)
-                stmts.append(sqlite_query)
-            return ";\n".join(stmts)
-
-        # ── 단일 포지셔널 세트 (tuple 또는 스칼라 list) ──
-        seq = paremeter if isinstance(paremeter, tuple) else tuple(paremeter)
-        for i, v in enumerate(seq, 1):
-            sqlite_query = sqlite_query.replace(f"?{i}", quote(v))
-        for v in seq:
-            sqlite_query = sqlite_query.replace('?', quote(v), 1)
-        return sqlite_query
-
-    return sqlite_query
-
-def interceptor_db_execute(fn, db_info, *args, **kwargs):
-    ctx = TraceContextManager.getLocalContext()
-    # sendDebugProfile(ctx, 'interceptor_db_execute step -1')
-    self = args[0]
-    db_type = db_info.get('type')
-    query = None
-
-    if db_type == "neo4j":
-        try:
-            query = neo4jQuery(args[1], kwargs)
-        except Exception as e:
-            pass
-
-    elif db_type == "sqlite" and len(args) > 2:
-        try:
-            query = sqliteQuery(args[1],args[2])
-        except Exception as e:
-            pass
-
-    else:
-        if len(args) > 2 and type(args[2]) == dict and args[2]:
-            try:
-                query = args[1] % addQuoteDict(args[2])
-            except Exception as e:
-                pass
-        if len(args) > 2 and type(args[2]) in (list, tuple) and args[2]:
-            try:
-                query = args[1] % addQuoteList(args[2])
-            except Exception as e:
-                pass
-    try:
-        if not query:
-            query = args[1].decode()
-    except Exception as e:
-        query = args[1]
-
-    if not query:
-        return fn(*args, **kwargs)
-
-    start_time = DateUtil.nowSystem()
-    ctx.start_time = start_time
-    ctx.active_sqlhash = query
-    try:
-        callback = fn(*args, **kwargs)
-        return callback
-    except Exception as e:
-        interceptor_step_error(e)
-    finally:
-        datas = [ctx.lctx.get('dbc', ''), query, str(self.rowcount)]
-        ctx.elapsed = DateUtil.nowSystem() - start_time
-        async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx, datas)
-        count = self.rowcount
-
-        if (count is not None) and (count > -1):
-            desc = '{0}: {1}'.format('Fetch count', count)
-            datas = [' ', ' ', desc]
-            ctx.elapsed = 0
-            async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-
-        ctx.active_sqlhash = 0
-
-
-def interceptor_db_close(fn, *args, **kwargs):
-    ctx = TraceContextManager.getLocalContext()
-    ctx.db_opening = False
-
-    if not conf.profile_dbc_close:
-        try:
-            return fn(*args, **kwargs)
-        except Exception as e:
-            interceptor_step_error(e)
-        finally:
-            return
-    start_time = DateUtil.nowSystem()
-    ctx.start_time = start_time
-
-    try:
-        callback = fn(*args, **kwargs)
-        return callback
-    except Exception as e:
-        interceptor_step_error(e)
-    finally:
-        text = 'DB: Close Connection.'
-        datas = [' ', ' ', text]
-        ctx.elapsed = DateUtil.nowSystem() - start_time
-        async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-
-
 check_seq = 1
 
 
