@@ -1,6 +1,6 @@
 from whatap.trace import get_dict
-from whatap.trace.mod.application.wsgi import trace_handler, \
-    interceptor_db_con, interceptor_db_execute, interceptor_db_close
+from whatap.trace.mod.application.wsgi import trace_handler
+from whatap.trace.mod.database.util import interceptor_db_con, interceptor_db_execute, interceptor_db_close
 
 db_info = {}
 
