@@ -6,7 +6,10 @@ from whatap.trace.trace_context_manager import TraceContextManager
 import whatap.net.async_sender as async_sender
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.util.date_util import DateUtil
-import sys, logging
+import os, sys, logging
+import traceback
+
+from whatap.util.frame_util import get_current_frame
 
 from pprint import pprint, pformat
 
@@ -30,7 +33,7 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
             return
         start_time = DateUtil.nowSystem()
         ctx.start_time = start_time
-        
+
         port_or_path = event.database_name
         text = 'mongodb://'
         if hasattr(event, 'connection_id') and len(event.connection_id) == 2:
@@ -46,7 +49,7 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
         datas = [text]
         ctx.elapsed = 0
         async_sender.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
-        
+
         start_time = DateUtil.nowSystem()
         ctx.start_time = start_time
 
@@ -60,7 +63,7 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
             else:
                 logging.debug(e, extra={'id': 'MON60'}, exc_info=True)
 
-        
+
     def __succeeded(self, event):
         ctx = TraceContextManager.getLocalContext()
         if not ctx:
@@ -84,7 +87,7 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
                 logging.debug(e, extra={'id': 'MON85', 'ctx.id':ctx.id}, exc_info=True)
             else:
                 logging.debug(e, extra={'id': 'MON85'}, exc_info=True)
-    
+
     def __failed(self, event):
         ctx = TraceContextManager.getLocalContext()
         if not ctx:
@@ -99,13 +102,13 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
         if hasattr(event, 'errtype'):
             errors.append(event.errtype)
         else:
-            errors.append(str())    
+            errors.append(str())
         errors.append(str())
 
         error = 'command: {}, operation_id: {}'.format(event.command_name, event.operation_id)
         if ctx.active_sqlhash:
             error +=' query: {}'.format(ctx.active_sqlhash)
-        frame = sys._current_frames().get(ctx.thread.ident)
+        frame = get_current_frame(ctx)
         if not frame:
             return
 
@@ -113,11 +116,11 @@ class WhatapMongoCmdEventListener(pymongo.monitoring.CommandListener):
             line = stack[0]
             line_num = stack[1]
             method_name = stack[2]
-            
-            if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
+
+            if 'whatap' + os.sep + 'trace' in line or 'threading.py' in line:
                 continue
             error += '{} ({}:{})\n'.format(method_name,line, line_num)
-        
+
         errors.append(error)
         ctx.elapsed = int(event.duration_micros / 1000)
         async_sender.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
@@ -140,7 +143,7 @@ def instrument_mongo_client(module):
 
             callback = fn(*args, **_kwargs)
             return callback
-        
+
         return trace
 
     def wrapper_find(fn):
@@ -149,7 +152,7 @@ def instrument_mongo_client(module):
             if ctx:
                 if len(args) > 1 and isinstance(args[1], dict):
                     query = pformat(args[1], compact=True)
-                    
+
                     ctx.active_sqlhash = query
             callback = fn(*args, **kwargs)
             return callback
@@ -163,4 +166,3 @@ def instrument_mongo_client(module):
                 module.monitoring.register(WhatapMongoCmdEventListener())
             if hasattr(module, 'collection') and hasattr(module.collection, 'Collection'):
                 module.collection.Collection.find = wrapper_find(module.collection.Collection.find)
-
