@@ -8,6 +8,11 @@ import whatap.io as whatapio
 loguru_injection_processed = False
 def instrument_loguru(module):
     global loguru_injection_processed
+
+    
+    if not conf.trace_loguru_enabled:
+        return
+
     def wrapper(fn):
         def trace(*args, **kwargs):
             if not conf.trace_loguru_enabled:
@@ -69,6 +74,10 @@ def instrument_loguru(module):
 logging_injection_processed = False
 def instrument_logging(module):
     global logging_injection_processed
+
+    if not conf.trace_logging_enabled:
+        return
+
     def wrapper(fn):
         def trace(*args, **kwargs):
             if not conf.trace_logging_enabled:
