@@ -1,3 +1,4 @@
+import os
 import sys
 import atexit
 import time
@@ -15,6 +16,11 @@ from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.trace.mod.application.wsgi import trace_handler
 from whatap import logging
 
+
+import threading
+
+from whatap.util.frame_util import get_current_frame
+
 def trace_handler(fn, start=False, preload=None):
     def handler(func):
         @wraps(func)
@@ -109,7 +115,7 @@ def error_interceptor(error_msg,error_type,ctx):
     errors.append(error_type)
     errors.append(error_msg)
 
-    frame = sys._current_frames().get(ctx.thread.ident)
+    frame = get_current_frame(ctx)
     if not frame:
         return
 
@@ -118,8 +124,7 @@ def error_interceptor(error_msg,error_type,ctx):
         line_num = stack[1]
         method_name = stack[2]
 
-        if line.find('/whatap/trace') > -1 or line.find(
-                '/threading.py') > -1:
+        if 'whatap' + os.sep + 'trace' in line or 'threading.py' in line:
             continue
         error += '{} ({}:{})\n'.format(method_name, line, line_num)
 
@@ -275,4 +280,4 @@ def instrument_standalone_multiple():
 
         return trace_and_patch_profiler
 
-    sys.settrace(trace_and_patch_profiler)
\ No newline at end of file
+    sys.settrace(trace_and_patch_profiler)
