@@ -1,4 +1,5 @@
 import atexit
+import os
 import sys
 import traceback
 import time
@@ -11,6 +12,7 @@ import whatap.net.async_sender as async_sender
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap import logging
 
+from whatap.util.frame_util import get_current_frame
 
 ctx = None
 
@@ -26,7 +28,7 @@ sys.excepthook = global_exception_handler
 
 
 def standalone_error(e, ctx=None):
-    
+
     if not ctx:
         ctx = TraceContextManager.getLocalContext()
     if not ctx:
@@ -43,12 +45,12 @@ def standalone_error(e, ctx=None):
     errors.append(error_message)
 
     error_stack = ''
-    frame = sys._current_frames().get(ctx.thread.ident)
+    frame = get_current_frame(ctx)
     if not frame:
         return
 
     for stack in traceback.extract_stack(frame):
-        if '/whatap/trace' in stack.filename or '/threading.py' in stack.filename:
+        if 'whatap' + os.sep + 'trace' in stack.filename or 'threading.py' in stack.filename:
             continue
         error_stack += f'{stack.name} ({stack.filename}:{stack.lineno})\n'
 
@@ -59,8 +61,8 @@ def standalone_error(e, ctx=None):
         datas = [' ', ' ', desc]
         ctx.start_time = DateUtil.nowSystem()
         async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-        
-    
+
+
 
 
 @atexit.register
@@ -119,5 +121,5 @@ def instrument_standalone_single():
              ctx.http_method
              ]
 
-    
-    async_sender.send_packet(PacketTypeEnum.TX_START, ctx, datas)
\ No newline at end of file
+
+    async_sender.send_packet(PacketTypeEnum.TX_START, ctx, datas)
